@@ -1,14 +1,13 @@
 
 package Text::Editor::Vip;
-
 use strict;
+use warnings ;
 
 BEGIN 
 {
 use Exporter ();
 use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-
-$VERSION     = 0.01_1;
+$VERSION     = '0.04';
 @ISA         = qw (Exporter);
 @EXPORT      = qw ();
 @EXPORT_OK   = qw ();
@@ -16,26 +15,14 @@ $VERSION     = 0.01_1;
 }
 
 
-
 =head1 NAME
 
-Text::Editor::Vip - Text editor for Perl and other languages
-
-=head1 SYNOPSIS
-
-  use Text::Editor::Vip
-  
+Text::Editor::Vip - Perl Editor
 
 =head1 DESCRIPTION
 
 See the README file.
 
-=head1 USAGE
-
-=head1 BUGS
-
-=head1 SUPPORT
-
 =head1 AUTHOR
 
   Nadim iibn Hamouda El Khemir
@@ -55,17 +42,4 @@ perl(1).
 
 =cut
 
-sub new
-{
-my ($class, %parameters) = @_;
-
-my $self = bless ({}, ref ($class) || $class);
-
-return ($self);
-}
-
-
-1 ; 
-
-__END__
-
+1 ;
\ No newline at end of file
